Internal function that creates a ggplot2 layer to add horizontal lines corresponding to the original model's 95
.add_ci_lines(orig_results, ci_lines_color)A ggplot2 layer (via geom_hline) that can be added to a plot.
A data frame containing the original model's estimates. It must
include the columns lowerCL and upperCL representing the lower and upper
confidence limits, respectively.
Character string specifying the color for the confidence interval lines.
Facundo Decunta - fdecunta@agro.uba.ar
These lines help visualize how the leave-one-out effect size estimates compare to the overall model estimate.