Rdocumentation
powered by
Learn R Programming
orchaRd (version 2.2.1)
.bbp_kg_labels: Add k and g annotation labels to bubble plot.
Description
Add k and g annotation labels to bubble plot.
Usage
.bbp_kg_labels(k, g, k.pos, kg_labels)
Arguments