Learn R Programming

orchaRd (version 2.2.1)

.calc.kurtosis: .calc.kurtosis

Description

Computes the excess kurtosis of a numeric vector using small sample correction.

Usage

.calc.kurtosis(x)

Value

A numeric value representing the kurtosis estimate or variance.

Arguments

x

A numeric vector.