Learn R Programming

orchaRd (version 2.2.1)

.calc.skewness: .calc.skewness

Description

Computes the skewness of a numeric vector using small sample correction.

Usage

.calc.skewness(x)

Value

A numeric value representing the skewness estimate or variance.

Arguments

x

A numeric vector.