.column_is_categorical: Check if Column is Categorical
Description
Determines if a column can be used as a categorical variable.
Valid categorical variables include:
- Character vectors
- Factors
- Integer values (common for ID numbers used as factors)
Usage
.column_is_categorical(col)
Value
logical. TRUE if the column can be used as a category, FALSE otherwise
Arguments
- col
vector. A vector to check (character, factor, or numeric)
Author
Facundo Decunta - fdecunta@agro.uba.ar