Learn R Programming

orchaRd (version 2.2.1)

.create_tmp_phylo_matrix: Create Temporary Phylogenetic Matrix For Leave-One-Out Analysis

Description

Creates a correlation matrix from a phylogenetic tree for the species remaining in the data subset during leave-one-out analysis.

Usage

.create_tmp_phylo_matrix(data, phylo_args)

Value

A phylogenetic correlation matrix for the species in the data subset.

Arguments

data

A data frame containing the variables specified in phylo_args, representing the current data subset after removing one group.

phylo_args

A list of arguments for the phylogenetic matrix calculation, including:

  • tree: A phylogenetic tree object of class "phylo"

  • species_colname: Name of the column in the data that contains species names

Author

Facundo Decunta - fdecunta@agro.uba.ar