Learn R Programming

orchaRd (version 2.2.1)

.extract_model_data: Extract model data used in metafor model

Description

Gets the data actually used to fit a metafor model, after applying any subset and removing rows with missing values.

Usage

.extract_model_data(model)

Value

A data frame of the used observations.

Arguments

model

A metafor model object.