Extracts and aggregates effect size data from each leave-one-out iteration into a single data frame. Applies mod_results() to each model and combines the resulting data values.
.get_effectsizes(outputs, group)A data frame of effect sizes with a column 'moderator' indicating the omitted group. Contains the same structure as the data element from mod_results() for each model iteration.
A named list of model objects from leave-one-out analysis where each name corresponds to the omitted group ID.
A character string specifying the grouping variable used in the analysis.
Facundo Decunta - fdecunta@agro.uba.ar