Learn R Programming

orchaRd (version 2.2.1)

.get_results: Get the output from mod_results

Description

Take the inputs passed to plotting functions and make sure to convert them into the results from mod_results.

Usage

.get_results(object, mod, group, N, by, at, weights, upper = TRUE)

Arguments