Learn R Programming

orchaRd (version 2.2.1)

.is_metafor_object: Check if Object is from metafor Package

Description

Verifies if an object is of class rma.mv, rma, rma.uni, or robust.rma

Usage

.is_metafor_object(obj)

Value

logical. TRUE if the object is from metafor package, FALSE otherwise

Arguments

obj

object. An R object to check for metafor class inheritance

Author

Facundo Decunta - fdecunta@agro.uba.ar