Learn R Programming

orchaRd (version 2.2.1)

.is_model_valid: Validate Model Argument

Description

Checks if a model argument is valid for meta-analysis: - It is not missing or NULL - It is a metafor package object (rma.mv, rma, etc.)

Usage

.is_model_valid(model)

Value

logical. TRUE if the model is valid, otherwise stops with an error message

Arguments

model

object. A model object from the metafor package (rma.mv, rma, rma.uni, or robust.rma)

Author

Facundo Decunta - fdecunta@agro.uba.ar