Learn R Programming

orchaRd (version 2.2.1)

.orcd_k_and_g: Add k and g to base orchard plot

Description

Add k and g to base orchard plot

Usage

.orcd_k_and_g(
  k,
  k.pos,
  g,
  data_trim,
  mod_table,
  flip = TRUE,
  k.size = 3.5,
  est = FALSE,
  est.size = 3
)

Value

ggplot object with added text annotations.

Arguments

k.pos

Position for the annotations. Can be "right", "left", or a numeric value specifying the y-coordinate.

g

Logical. If TRUE, adds the g values in parentheses after k.

data_trim

A data frame containing the yi values used to calculate annotation positions.

mod_table

A data frame containing the k (and optionally g) values for each group.