Learn R Programming

orchaRd (version 2.2.1)

.order_mod: Reorder the tree

Description

Reorder the position of the moderators in the plot by reordering the factors in the model table and the data.

Usage

.order_mod(results, mod.order)

Arguments