Learn R Programming

orchaRd (version 2.2.1)

.prune_tree: Prune Phylogenetic Tree For Leave-One-Out Analysis

Description

Removes species from a phylogenetic tree that are not present in the current data subset during leave-one-out analysis.

Usage

.prune_tree(tree, species_names)

Value

A pruned phylogenetic tree containing only the tips for species in species_names.

Arguments

tree

A phylogenetic tree object of class "phylo".

species_names

A vector of species names that should remain in the pruned tree. These are the species present in the current data subset.

Author

Daniel Noble - daniel.noble@anu.edu.au

Facundo Decunta - fdecunta@agro.uba.ar