Computes a SAFE bootstrap estimate of the effect size and its variance for dependent samples.
.safe_lnM_dep(
x1bar,
x2bar,
sd1,
sd2,
n,
r,
min_kept = 2000,
chunk_init = 4000,
chunk_max = 2e+06,
max_draws = Inf,
patience_noaccept = 5,
seed = 565
)A list containing the point estimate, variance, number of kept samples, total draws, number of attempts, and status.
Mean of group 1.
Mean of group 2.
Standard deviation of group 1.
Standard deviation of group 2.
Sample size (assumed equal for both groups).
Correlation between the two groups.
Minimum number of accepted bootstrap samples to keep. Default is 2000.
Initial chunk size for bootstrap sampling. Default is 4000.
Maximum chunk size for bootstrap sampling. Default is 2e6.
Maximum total number of bootstrap draws. Default is Inf.
Number of consecutive chunks with no accepted samples before stopping. Default is 5.
Random seed for reproducibility. Default is 565.