Learn R Programming

orchaRd (version 2.2.1)

.safe_lnM_indep: SAFE bootstrap : independent samples

Description

Computes a SAFE bootstrap estimate of the effect size and its variance for independent samples.

Usage

.safe_lnM_indep(
  x1bar,
  x2bar,
  sd1,
  sd2,
  n1,
  n2,
  min_kept = 2000,
  chunk_init = 4000,
  chunk_max = 2e+06,
  max_draws = Inf,
  patience_noaccept = 5,
  seed = 565
)

Value

A list containing the point estimate, variance, number of kept samples, total draws, number of attempts, and status.

Arguments

x1bar

Mean of group 1.

x2bar

Mean of group 2.

sd1

Standard deviation of group 1.

sd2

Standard deviation of group 2.

n1

Sample size of group 1.

n2

Sample size of group 2.

min_kept

Minimum number of accepted bootstrap samples to keep. Default is 2000.

chunk_init

Initial chunk size for bootstrap sampling. Default is 4000.

chunk_max

Maximum chunk size for bootstrap sampling. Default is 2e6.

max_draws

Maximum total number of bootstrap draws. Default is Inf.

patience_noaccept

Number of consecutive chunks with no accepted samples before stopping. Default is 5.

seed

Random seed for reproducibility. Default is 565.