Internal function to determine the appropriate color palette based on the number of elements in the leave-one-out results.
.set_color_palette(loo_results)A list with two components:
A ggplot2 scale object for mapping colors.
A ggplot2 scale object for mapping fill colors.
Output from leave_one_out(), which contains the leave-one-out analysis results.
Facundo Decunta - fdecunta@agro.uba.ar
When the number of rows in the leave-one-out results exceeds 20, a viridis color scale is used. Otherwise, a color-blind friendly manual palette is applied.