Learn R Programming

orchaRd (version 2.2.1)

.set_width: Set width for ggplot2::position_dodge2()

Description

When the model use has some condition, the plot needs separation for estimates from the same moderator. This function adds space when a condition is present.

Usage

.set_width(mod_table)

Arguments