Learn R Programming

orchaRd (version 2.2.1)

.sv_jack: Jackknife Estimation of Skewness and Kurtosis for computing sampling variances

Description

Computes jackknife estimate and standard error for skewness and kurtosis.

Usage

.sv_jack(
  x,
  bias.correct = TRUE,
  return.replicates = FALSE,
  type = c("skew", "kurt")
)

Value

A list with estimate (`est`), bias-corrected estimate (`est_bc`), variance, and standard error.

Arguments

x

A numeric vector.

bias.correct

Logical, whether to apply bias correction. Default is TRUE.

return.replicates

Logical, whether to return jackknife replicates. Default is FALSE.

type

Character, either "skew" or "kurt" to specify the type of statistic.