Learn R Programming

orchaRd (version 2.2.1)

.validate_robust_args: Validate Robust Variance Estimation Arguments

Description

Validates that robust_args contains the required parameters and that they reference valid columns in the data. Ensures that the cluster variable exists in the provided model data.

Usage

.validate_robust_args(model_data, robust_args)

Value

The validated robust_args list if all checks pass.

Arguments

model_data

A data frame containing the variables used in the model.

robust_args

A list of arguments for the metafor::robust function.

Author

Facundo Decunta - fdecunta@agro.uba.ar