Learn R Programming

orchaRd (version 2.2.1)

.validate_vcalc_args: Validate Variance-Covariance Calculation Arguments

Description

Ensures that the arguments provided for variance-covariance calculation are valid and refer to existing variables in the model data. Performs checks on the structure and content of the vcalc_args list.

Usage

.validate_vcalc_args(model_data, vcalc_args)

Value

The validated vcalc_args list if all checks pass.

Arguments

model_data

A data frame containing the variables used in the model.

vcalc_args

A list of arguments for the metafor::vcalc function.

Author

Facundo Decunta - fdecunta@agro.uba.ar