Learn R Programming

orchaRd (version 2.2.1)

firstup: firstup

Description

Uppercase moderator names

Usage

firstup(x, upper = TRUE)

Value

Returns a character string with all combinations of the moderator level names with upper case first letters

Arguments

x

a character string

upper

logical indicating if the first letter of the character string should be capitalized. Defaults to TRUE.

Author

Shinichi Nakagawa - s.nakagawa@unsw.edu.au

Daniel Noble - daniel.noble@anu.edu.au