This function adds a corrected meta-analytic mean, sensu Yang et al. 2023, confidence interval and text annotation to an intercept only orchard plot.
geom_pub_stats_yang(
data,
col = "red",
plotadj = -0.05,
textadj = 0.05,
branch.size = 1.2,
trunk.size = 3
)A list of ggplot2 objects to be added to the orchard plot.
The data frame containing the corrected meta-analytic mean and confidence intervals.
The colour of the mean and confidence intervals.
The adjustment to the x-axis position of the mean and confidence intervals.
The adjustment to the y-axis position of the mean and confidence intervals for the text displaying the type of correction.
Size of the confidence intervals.
Size of the mean, or central point.
Daniel Noble - daniel.noble@anu.edu.au