Learn R Programming

orchaRd (version 2.2.1)

get_data_raw_cont: get_data_raw_cont

Description

Collects and builds the data used to fit the rma.mv or rma model in metafor when a continuous variable is fit within a model object.

Usage

get_data_raw_cont(model, mod, group, N = NULL, by)

Value

Returns a data frame

Arguments

model

rma.mv object.

mod

the moderator variable.

group

The grouping variable that one wishes to plot beside total effect sizes, k. This could be study, species or whatever other grouping variable one wishes to present sample sizes.

N

The name of the column in the data specifying the sample size, N. Defaults to NULL so that precision is plotted instead of sample size.

by

Character name(s) of the 'condition' variables to use for grouping into separate tables.

Author

Shinichi Nakagawa - s.nakagawa@unsw.edu.au

Daniel Noble - daniel.noble@anu.edu.au