Learn R Programming

orchaRd (version 2.2.1)

get_ints_dat: get_ints_dat

Description

This function extracts the corrected meta-analytic mean and confidence intervals from a model object.

Usage

get_ints_dat(model, type = c("bc", "br"))

Value

A list containing the corrected meta-analytic mean and confidence intervals, and a label for the plot.

Arguments

model

The rma model object containing the corrected meta-analytic mean and confidence intervals.

type

The type of correction to extract the corrected meta-analytic mean and confidence intervals from. "br" (i.e., Bias Robust) for Yang et al. 2023, "bc" (i.e., Bias-Corrected) for Nakagawa et al. 2023.

Author

Daniel Noble - daniel.noble@anu.edu.au