Learn R Programming

orchaRd (version 2.2.1)

m1_ml: m1_ml

Description

M1 for mulilevel meta-analytic models, based on Yang et al. (2023). Under multilevel models, we can have multiple M1 - TODO - we need to cite original M1 paper

Usage

m1_ml(model, boot = NULL)

Value

A data frame containing all the model results including mean effect size estimate, confidence, and prediction intervals

Arguments

model

Model object of class rma.mv or rma. Currently only model objects using the mods argument work (e.g., mod = ~1).

boot

Number of simulations to run to produce 95 percent confidence intervals for M1. Default is NULL, where only the point estimate is provided.

Author

Shinichi Nakagawa - s.nakagawa@unsw.edu.au

Daniel Noble - daniel.noble@anu.edu.au

References

TODO

Examples

Run this code
# \donttest{
library(metafor)
# NOTE: boot is set LOW here for speed; use boot >= 1000 in practice.
data(english)
english <- escalc(measure = "SMD", n1i = NStartControl,
  sd1i = SD_C, m1i = MeanC, n2i = NStartExpt, sd2i = SD_E,
  m2i = MeanE, var.names = c("SMD", "vSMD"), data = english)
english_MA <- rma.mv(yi = SMD, V = vSMD,
  random = list(~1 | StudyNo, ~1 | EffectID), data = english)
m1_ml(english_MA)
m1_ml(english_MA, boot = 10)
# }

Run the code above in your browser using DataLab