Learn R Programming

orchaRd (version 2.2.1)

ml_cvh2: ml_cvh2

Description

Calculated CVH2 for mulilevel meta-analytic models

Usage

ml_cvh2(model)

Value

A named numeric vector of CVH2 values (the coefficient of variation of the heterogeneity, on the variance scale). The first element, CVH2_Total, is the overall value across all random effects; each remaining element (named CVH2_<level> after a random-effect level of the model) is the value for that level.

Arguments

model

Model object of class rma.mv or rma.