Learn R Programming

orchaRd (version 2.2.1)

ml_m2: ml_m2

Description

Calculated CV for mulilevel meta-analytic models

Usage

ml_m2(model)

Value

A named numeric vector of M2 heterogeneity values (a proportion-type index on the variance scale, bounded between 0 and 1). The first element, M2_Total, is the overall value across all random effects; each remaining element (named M2_<level> after a random-effect level of the model) is the value for that level.

Arguments

model

Model object of class rma.mv or rma.