This function is useful to see how sensitive is the overall effect size estimated by a meta-analytic model to exclusion of each element from a group.
The y-axis shows the elements from the group. For each one, the plot shows the result from the model that left-out that element.
For each model, the plot shows the effect sizes, overall effect estimate with confidence and prediction intervals, and "ghost points".
This "ghost points" are the effect sizes left out and they are shown as empty points. They can be ommited setting 'ghost_points' to FALSE.
The plot also shows 95
as red dotted lines. The arguments 'ci_lines' and 'ci_lines_color' allow to remove this lines or select their color.
The function internally sets a color palette for the plot. If more than 20 elements are in the group, a viridis
palette is used. Otherwise, a color-blind friendly palette is applied by default.