Learn R Programming

orchaRd (version 2.2.1)

pred_interval_esmeans: pred_interval_esmeans

Description

Function to get prediction intervals (credibility intervals) from esmeans objects (metafor).

Usage

pred_interval_esmeans(model, mm, mod, ...)

Value

A data frame built from summary() of the emmeans object: one row per level of the moderator giving the estimated marginal mean and its confidence limits, plus two added columns, lower.PI and upper.PI, containing the lower and upper bounds of the prediction (credibility) interval.

Arguments

model

rma.mv object.

mm

result from emmeans::emmeans object.

mod

Moderator of interest.

...

other arguments passed to function.

Author

Shinichi Nakagawa - s.nakagawa@unsw.edu.au

Daniel Noble - daniel.noble@anu.edu.au