Learn R Programming

orchaRd (version 2.2.1)

transform_mod_results: Transform effect sizes in an orchard object

Description

Applies a transformation to the effect sizes and their confidence/prediction intervals from a model result object returned by mod_results.

Usage

transform_mod_results(results, transfm, n_transfm)

Value

A modified list object of class orchard, where the effect size estimates and their intervals in both mod_table and data are transformed accordingly.

Arguments

results

An object of class orchard, the output from mod_results.

transfm

A character string specifying the transformation to apply. Options include: - "none": No transformation (default) - "tanh": Hyperbolic tangent transformation - "invlogit": Inverse logit transformation - "percentr": Percentage relative change transformation - "percent": Percentage transformation - "inv_ft": Inverse Freeman-Tukey (double arcsine) transformation for proportions (use with caution)

n_transfm

A numeric vector of sample sizes, used only when transfm = "inv_ft". Defaults to NULL.