Internal function to add ghost points to an orchard plot.
.add_ghost_points(data, transfm)A ggplot2 layer (via geom_quasirandom) displaying the ghost points.
Data from the leave-one-out analysis, specifically the data component
containing effect sizes (yi), variances (vi), and grouping variable (stdy).
Character string indicating the transformation to be applied to the data.
See orchard_leave1out() for available transformation options.
Facundo Decunta - fdecunta@agro.uba.ar
Ghost points represent the effect sizes that were omitted in each leave-one-out iteration. They are plotted as empty points with reduced opacity to indicate their auxiliary role.