Creates a correlation matrix from a phylogenetic tree for the species remaining in the data subset during leave-one-out analysis.
.create_tmp_phylo_matrix(data, phylo_args)A phylogenetic correlation matrix for the species in the data subset.
A data frame containing the variables specified in phylo_args, representing the current data subset after removing one group.
A list of arguments for the phylogenetic matrix calculation, including:
tree: A phylogenetic tree object of class "phylo"
species_colname: Name of the column in the data that contains species names
Facundo Decunta - fdecunta@agro.uba.ar