Checks if a group variable meets the requirements for analysis: - It is not missing or NULL - It exists in the data frame - It is a categorical variable - It has no missing values
.is_group_valid(data, column_name)logical. TRUE if the group variable is valid, otherwise stops with an error message
data.frame. A data frame containing the group variable
character. The name of the column to check
Facundo Decunta - fdecunta@agro.uba.ar