powered by
Verifies if an object is of class rma.mv, rma, rma.uni, or robust.rma
.is_metafor_object(obj)
logical. TRUE if the object is from metafor package, FALSE otherwise
object. An R object to check for metafor class inheritance
Facundo Decunta - fdecunta@agro.uba.ar