powered by
Checks if a model argument is valid for meta-analysis: - It is not missing or NULL - It is a metafor package object (rma.mv, rma, etc.)
.is_model_valid(model)
logical. TRUE if the model is valid, otherwise stops with an error message
object. A model object from the metafor package (rma.mv, rma, rma.uni, or robust.rma)
Facundo Decunta - fdecunta@agro.uba.ar