Add k and g to base orchard plot
.orcd_k_and_g(
k,
k.pos,
g,
data_trim,
mod_table,
flip = TRUE,
k.size = 3.5,
est = FALSE,
est.size = 3
)ggplot object with added text annotations.
Position for the annotations. Can be "right", "left", or a numeric value specifying the y-coordinate.
Logical. If TRUE, adds the g values in parentheses after k.
A data frame containing the yi values used to calculate annotation positions.
A data frame containing the k (and optionally g) values for each group.