Removes species from a phylogenetic tree that are not present in the current data subset during leave-one-out analysis.
.prune_tree(tree, species_names)A pruned phylogenetic tree containing only the tips for species in species_names.
A phylogenetic tree object of class "phylo".
A vector of species names that should remain in the pruned tree. These are the species present in the current data subset.
Daniel Noble - daniel.noble@anu.edu.au
Facundo Decunta - fdecunta@agro.uba.ar