Validates that robust_args contains the required parameters and that they reference valid columns in the data. Ensures that the cluster variable exists in the provided model data.
.validate_robust_args(model_data, robust_args)The validated robust_args list if all checks pass.
A data frame containing the variables used in the model.
A list of arguments for the metafor::robust function.
Facundo Decunta - fdecunta@agro.uba.ar