Ensures that the arguments provided for variance-covariance calculation are valid and refer to existing variables in the model data. Performs checks on the structure and content of the vcalc_args list.
.validate_vcalc_args(model_data, vcalc_args)The validated vcalc_args list if all checks pass.
A data frame containing the variables used in the model.
A list of arguments for the metafor::vcalc function.
Facundo Decunta - fdecunta@agro.uba.ar