Learn R Programming

orchaRd (version 2.2.1)

Zr_to_r: Zr_to_r

Description

Converts Zr back to r (Pearson's correlation coefficient)

Usage

Zr_to_r(df)

Value

A data frame containing all the model results including mean effect size estimate, confidence and prediction intervals with estimates converted back to r

Arguments

df

data frame of results of class 'orchard'

Author

Shinichi Nakagawa - s.nakagawa@unsw.edu.au

Daniel Noble - daniel.noble@anu.edu.au