powered by
Converts Zr back to r (Pearson's correlation coefficient)
Zr_to_r(df)
A data frame containing all the model results including mean effect size estimate, confidence and prediction intervals with estimates converted back to r
data frame of results of class 'orchard'
Shinichi Nakagawa - s.nakagawa@unsw.edu.au
Daniel Noble - daniel.noble@anu.edu.au