powered by
Computes the difference in correlation coefficients between two groups along with associated sampling variance for meta-analysis. The correlation and associated sample size or the data frame of the two variables can be provided
cor_diff(cor1 = NULL, cor2 = NULL, n1 = NULL, n2 = NULL, x1 = NULL, x2 = NULL)
A data frame with the difference in correlations and the sampling variances of the difference.
Numeric, the correlation coefficient for group 1.
Numeric, the correlation coefficient for group 2.
Integer, the sample size for group 1.
Integer, the sample size for group 2.
A numeric vector for group 1.
A numeric vector for group 2.
# \donttest{ set.seed(982) # Example with known correlations cor_diff(0.5, 0.3, 100, 100) cor_diff(0.2, 0.4, 40, 40) # }
Run the code above in your browser using DataLab