powered by
Uppercase moderator names
firstup(x, upper = TRUE)
Returns a character string with all combinations of the moderator level names with upper case first letters
a character string
logical indicating if the first letter of the character string should be capitalized. Defaults to TRUE.
Shinichi Nakagawa - s.nakagawa@unsw.edu.au
Daniel Noble - daniel.noble@anu.edu.au