Collects and builds the data used to fit the rma.mv or rma model in metafor when a continuous variable is fit within a model object.
get_data_raw_cont(model, mod, group, N = NULL, by)Returns a data frame
rma.mv object.
the moderator variable.
The grouping variable that one wishes to plot beside total effect sizes, k. This could be study, species or whatever other grouping variable one wishes to present sample sizes.
The name of the column in the data specifying the sample size, N. Defaults to NULL so that precision is plotted instead of sample size.
Character name(s) of the 'condition' variables to use for grouping into separate tables.
Shinichi Nakagawa - s.nakagawa@unsw.edu.au
Daniel Noble - daniel.noble@anu.edu.au