This function extracts the corrected meta-analytic mean and confidence intervals from a model object.
get_ints_dat(model, type = c("bc", "br"))A list containing the corrected meta-analytic mean and confidence intervals, and a label for the plot.
The rma model object containing the corrected meta-analytic mean and confidence intervals.
The type of correction to extract the corrected meta-analytic mean and confidence intervals from. "br" (i.e., Bias Robust) for Yang et al. 2023, "bc" (i.e., Bias-Corrected) for Nakagawa et al. 2023.
Daniel Noble - daniel.noble@anu.edu.au