Calculated CVH1 for mulilevel meta-analytic models
ml_cvh1(model)A named numeric vector of CVH1 values (the coefficient of variation of the heterogeneity, on the standard-deviation scale). The first element, CVH1_Total, is the overall value across all random effects; each remaining element (named CVH1_<level> after a random-effect level of the model) is the value for that level.
Model object of class rma.mv or rma.