Checks if `model` is a valid metafor model object. The model must be one of the following classes: `robust.rma`, `rma.mv`, `rma`, or `rma.uni`.
model_is_valid(model)Logical `TRUE` if the `model` argument is valid. If the model is missing or not of an accepted class, the function stops with an error message.
An object representing a fitted metafor model. It should be of class `robust.rma`, `rma.mv`, `rma`, or `rma.uni`.