Function to get prediction intervals (credibility intervals) from esmeans objects (metafor).
pred_interval_esmeans(model, mm, mod, ...)A data frame built from summary() of the emmeans object: one row per level of the moderator giving the estimated marginal mean and its confidence limits, plus two added columns, lower.PI and upper.PI, containing the lower and upper bounds of the prediction (credibility) interval.
rma.mv object.
result from emmeans::emmeans object.
Moderator of interest.
other arguments passed to function.
Shinichi Nakagawa - s.nakagawa@unsw.edu.au
Daniel Noble - daniel.noble@anu.edu.au