Applies a transformation to the effect sizes and their confidence/prediction intervals from a model result object returned by mod_results.
transform_mod_results(results, transfm, n_transfm)A modified list object of class orchard, where the effect size estimates and their intervals in both mod_table and data are transformed accordingly.
An object of class orchard, the output from mod_results.
A character string specifying the transformation to apply. Options include:
- "none": No transformation (default)
- "tanh": Hyperbolic tangent transformation
- "invlogit": Inverse logit transformation
- "percentr": Percentage relative change transformation
- "percent": Percentage transformation
- "inv_ft": Inverse Freeman-Tukey (double arcsine) transformation for proportions (use with caution)
A numeric vector of sample sizes, used only when transfm = "inv_ft". Defaults to NULL.